# Documentation
The documentation is generated using [Sphinx](http://www.sphinx-doc.org/en/master/).

If you want to generate the documentation, you can run:
Linux:
```
    make html
```

Windows:
```
sphinx-build -b html . _build
```

# Installation
The following packages are required to generate the documentation:
```
    pip install Sphinx
    pip install Flask-Sphinx-Themes
```

# Read The Docs
You can also find the documentation on see [this site](http://flask-monitoringdashboard.readthedocs.io).